@@ -45,8 +45,9 @@ impl ShowIcons {
             Automatic,
         }
 
+        let force_icons = vars.get(vars::EZA_ICONS_AUTO).is_some();
         let mode_opt = matches.get(&flags::ICONS)?;
-        if !matches.has(&flags::ICONS)? && mode_opt.is_none() {
+        if !force_icons && !matches.has(&flags::ICONS)? && mode_opt.is_none() {
             return Ok(Self::Never);
         }
 
